@@ -33,12 +33,12 @@ class Name:
         assert isinstance(obj, dict)
         from slapp_py.core_classes.source import Source
         return Name(
-            value=obj.get("Value", ""),
+            value=obj.get("N", ""),
             sources=Source.deserialize_source_uuids(obj)
         )
 
     def to_dict(self) -> dict:
-        result: dict = {'Value': self.value}
+        result: dict = {'N': self.value}
         if len(self.sources) > 0:
             result["S"] = serialize_uuids(self.sources)
         return result
