@@ -223,7 +223,7 @@ class SlappResponseObject:
                                        bracket.placements.players_by_placement[1]]
                     if p.guid.__str__() in first_place_ids:
                         from slapp_py.core_classes.builtins import NoTeam
-                        team = bracket.placements.teams_by_placement.get(place, set(NoTeam.guid))
+                        team = bracket.placements.teams_by_placement.get(place, {NoTeam.guid})
                         result.append((self.sources[source_id], bracket, team))
         return result
 
